# Generated by Django 2.2.1 on 2020-04-06 06:10

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('smpl_message_log', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='messagelog',
            options={'default_permissions': (), 'ordering': ('-created',)},
        ),
    ]




import markdown

from django.db import models
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.fields import GenericRelation

__all__ = [
    'MessageLog',
    'MessageLogs'
]


class MessageLogManager(models.Manager):

    def _add_message(self, level, message):
        return MessageLog.objects.create(
            level=level,
            message=message,
            content_type=self.content_type,
            object_id=self.pk_val
        )

    def info(self, message):
        return self._add_message(self.model.INFO, message)

    def debug(self, message):
        return self._add_message(self.model.DEBUG, message)

    def warning(self, message):
        return self._add_message(self.model.WARNING, message)

    def error(self, message):
        return self._add_message(self.model.ERROR, message)

    def critical(self, message):
        return self._add_message(self.model.CRITICAL, message)

    def success(self, message):
        return self._add_message(self.model.SUCCESS, message)


class MessageLog(models.Model):

    DEBUG = 'DEBUG'
    INFO = 'INFO'
    WARNING = 'WARNING'
    ERROR = 'ERROR'
    SUCCESS = 'SUCCESS'
    CRITICAL = 'CRITICAL'

    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE, db_index=True)
    object_id = models.CharField(max_length=255, null=True, blank=True, db_index=True)
    level = models.CharField(max_length=100)
    message = models.TextField()
    created = models.DateTimeField(auto_now_add=True)

    content_object = GenericForeignKey()
    objects = MessageLogManager()

    class Meta:
        default_permissions = ()
        ordering = ('-created',)

    def __str__(self):
        return self.message

    def as_html(self):
        return markdown.markdown(self.message)


class MessageLogs(GenericRelation):

    def __init__(self, **kwargs):
        super().__init__(MessageLog, **kwargs)



import setuptools
from os.path import join, dirname

import smpl_message_log

setuptools.setup(
    name='smpl-message-log',
    packages=setuptools.find_packages(),
    version=smpl_message_log.__version__,
    license='MIT',
    url='https://github.com/ilya-muhortov/smpl-message-log',
    long_description=open(join(dirname(__file__), 'README.md')).read(),
    long_description_content_type="text/markdown",
    install_requires=[
        'markdown',
    ],
)



# Generated by Django 2.2.1 on 2020-04-06 00:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='MessageLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.CharField(blank=True, db_index=True, max_length=255, null=True)),
                ('level', models.CharField(max_length=100)),
                ('message', models.TextField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
            options={
                'default_permissions': (),
            },
        ),
    ]
